@@ -60,6 +60,11 @@ CONNECTORS_REGISTRY = {
         'label': 'Facebook Insights',
         'logo': 'facebook_insights/facebook-insights.png',
     },
+    'facebook_ads': {
+        'connector': 'facebook_ads.facebook_ads_connector.FacebookAdsConnector',
+        'label': 'Facebook Ads',
+        'logo': 'facebook_ads/facebook_logo.png',
+    },
     'Github': {
         'connector': 'github.github_connector.GithubConnector',
         'label': 'Github Connector',
@@ -70,6 +75,11 @@ CONNECTORS_REGISTRY = {
         'label': 'Google Analytics',
         'logo': 'google_analytics/google-analytics.png',
     },
+    'GoogleAdwords': {
+        'connector': 'google_adwords.google_adwords_connector.GoogleAdwordsConnector',
+        'label': 'Google Adwords',
+        'logo': 'google_adwords/google_adwords.jpg',
+    },
     'GoogleBigQuery': {
         'connector': 'google_big_query.google_big_query_connector.GoogleBigQueryConnector',
         'label': 'Google Big Query',
@@ -184,6 +194,11 @@ CONNECTORS_REGISTRY = {
         'connector': 'snowflake.snowflake_connector.SnowflakeConnector',
         'logo': 'snowflake/snowflake.png',
     },
+    'Soap': {
+        'connector': 'soap.soap_connector.SoapConnector',
+        'label': 'Soap',
+        'logo': 'soap/soap.png',
+    },
     'ToucanToco': {
         'connector': 'toucan_toco.toucan_toco_connector.ToucanTocoConnector',
         'label': 'Toucan Toco',
